@@ -133,6 +133,7 @@ class Resources(SNPsResources):
 
     def get_genetic_map_HapMapII_GRCh37(self):
         """ Get International HapMap Consortium HapMap Phase II genetic map for Build 37.
+        [#InternationalHapMapConsortium]_ [#Auton2010]_
 
         Returns
         -------
@@ -141,10 +142,10 @@ class Resources(SNPsResources):
 
         References
         ----------
-        1. "The International HapMap Consortium (2007).  A second generation human haplotype
-           map of over 3.1 million SNPs.  Nature 449: 851-861."
-        2. "The map was generated by lifting the HapMap Phase II genetic map from build 35 to
-           GRCh37. The original map was generated using LDhat as described in the 2007 HapMap
+        .. [#InternationalHapMapConsortium] "The International HapMap Consortium (2007).  A second generation human
+           haplotype map of over 3.1 million SNPs.  Nature 449: 851-861."
+        .. [#Auton2010] "The map was generated by lifting the HapMap Phase II genetic map from build
+           35 to GRCh37. The original map was generated using LDhat as described in the 2007 HapMap
            paper (Nature, 18th Sept 2007). The conversion from b35 to GRCh37 was achieved using
            the UCSC liftOver tool. Adam Auton, 08/12/2010"
         """
@@ -157,11 +158,12 @@ class Resources(SNPsResources):
         return self._genetic_map
 
     def get_genetic_map_1000G_GRCh37(self, pop):
-        """ Get population-specific 1000 Genomes Project genetic map.
+        """ Get population-specific 1000 Genomes Project genetic map. [#Auton2013]_ [#Auton2015]_
 
         Notes
         -----
-        From `README_omni_recombination_20130507 <ftp://ftp.1000genomes.ebi.ac.uk/vol1/ftp/technical/working/20130507_omni_recombination_rates/README_omni_recombination_20130507>`_:
+        From `README_omni_recombination_20130507
+        <ftp://ftp.1000genomes.ebi.ac.uk/vol1/ftp/technical/working/20130507_omni_recombination_rates/README_omni_recombination_20130507>`_ [#Auton2013]_ :
 
             Genetic maps generated from the 1000G phased OMNI data.
 
@@ -185,9 +187,6 @@ class Resources(SNPsResources):
             estimate of 4Ne, allowing the population based rates to be converted to
             per-generation rates.
 
-            Adam Auton (adam.auton@einstein.yu.edu)
-            May 7th, 2013
-
         Returns
         -------
         dict
@@ -196,11 +195,11 @@ class Resources(SNPsResources):
 
         References
         ----------
-        1. Adam Auton (adam.auton@einstein.yu.edu), May 7th, 2013
-        2. The 1000 Genomes Project Consortium., Corresponding authors., Auton, A. et al. A
-           global reference for human genetic variation. Nature 526, 68–74 (2015).
+        .. [#Auton2013] Adam Auton, May 7th, 2013
+        .. [#Auton2015] The 1000 Genomes Project Consortium., Corresponding authors.,
+           Auton, A. et al. A global reference for human genetic variation. Nature 526, 68–74 (2015).
            https://doi.org/10.1038/nature15393
-        3. https://github.com/joepickrell/1000-genomes-genetic-maps
+        .. [#Pickrell] https://github.com/joepickrell/1000-genomes-genetic-maps
         """
         if self._genetic_map_name != pop:
             self._genetic_map = self._load_genetic_map_1000G_GRCh37(
@@ -415,7 +414,7 @@ class Resources(SNPsResources):
         df : pandas.DataFrame
             cytoBand table
         """
-        # adapted from chromosome plotting code (see [1]_)
+        # adapted from chromosome plotting code (see get_cytoBand_hg19 Ref. 1.)
         df = pd.read_csv(
             filename, names=["chrom", "start", "end", "name", "gie_stain"], sep="\t"
         )
